==> xpsql-0.9.1.tar.gz: XpSQL/sql/createfunction.sql <==
/**
 - createfunction.sql,v 1.1 2003/07/17 14:10:45 myui Exp
 */

BEGIN;

CREATE OR REPLACE FUNCTION Create_New_Document(VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' STRICT;
 
CREATE OR REPLACE FUNCTION XML_TagID(VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' STABLE STRICT;

CREATE OR REPLACE FUNCTION XML_AttID(VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' STABLE STRICT;
 
CREATE OR REPLACE FUNCTION XML_NSID(VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' STABLE STRICT;

CREATE OR REPLACE FUNCTION XML_PIID(VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' STABLE STRICT;

CREATE OR REPLACE FUNCTION Drop_Document(VARCHAR) RETURNS BOOL AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;
 
CREATE OR REPLACE FUNCTION Get_TagID(VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' IMMUTABLE STRICT;

CREATE OR REPLACE FUNCTION Get_AttID(VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' IMMUTABLE STRICT;
 
CREATE OR REPLACE FUNCTION Get_NSID(VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' IMMUTABLE STRICT;

CREATE OR REPLACE FUNCTION Get_PIID(VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' IMMUTABLE STRICT;

CREATE OR REPLACE FUNCTION CreateElement(INTEGER,VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;

CREATE OR REPLACE FUNCTION CreateProcessingInstruction(INTEGER,VARCHAR,VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;
 
CREATE OR REPLACE FUNCTION CreateTextNode(INTEGER,VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;

CREATE OR REPLACE FUNCTION CreateComment(INTEGER,VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;

CREATE OR REPLACE FUNCTION New_ChildElement(INTEGER,VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;

CREATE OR REPLACE FUNCTION New_ChildPI(INTEGER,VARCHAR,VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;

CREATE OR REPLACE FUNCTION New_ChildText(INTEGER,VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;

CREATE OR REPLACE FUNCTION New_ChildComment(INTEGER,VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;

CREATE OR REPLACE FUNCTION SetAttribute(INTEGER,VARCHAR,VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;

CREATE OR REPLACE FUNCTION SetNamespace(INTEGER,VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;

CREATE OR REPLACE FUNCTION SetNamespace(INTEGER,VARCHAR,VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;

CREATE OR REPLACE FUNCTION appendChild(INTEGER,INTEGER) RETURNS BOOL AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' STRICT;

CREATE OR REPLACE FUNCTION insertBefore(INTEGER,INTEGER) RETURNS BOOL AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' STRICT;

CREATE OR REPLACE FUNCTION StringValue(INTEGER) RETURNS TEXT AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' STABLE STRICT;

CREATE OR REPLACE FUNCTION cat_list(VARCHAR, VARCHAR) RETURNS VARCHAR AS
'
SELECT CASE
	WHEN $2 IS NULL OR $2 = '''' THEN $1
	WHEN $1 IS NULL OR $1 = '''' THEN $2
	ELSE $1 || $2
END
'LANGUAGE 'SQL';

--CREATE OR REPLACE FUNCTION IsUnited(INTEGER) RETURNS BOOLEAN AS
--'
--SELECT united FROM xml_path WHERE pathid = $1
--'LANGUAGE 'SQL';

CREATE AGGREGATE list(
	sfunc1=cat_list,
	basetype=VARCHAR,
	stype1=VARCHAR,
	initcond1=''
);

END;

==> xpsql-0.9.2a.tar.gz: XpSQL/sql/createfunction.sql <==
/**
 - createfunction.sql,v 1.1 2003/07/17 14:10:45 myui Exp
 */

BEGIN;

CREATE OR REPLACE FUNCTION Create_New_Document(VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' STRICT;
 
CREATE OR REPLACE FUNCTION XML_TagID(VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' STABLE STRICT;

CREATE OR REPLACE FUNCTION XML_AttID(VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' STABLE STRICT;
 
CREATE OR REPLACE FUNCTION XML_NSID(VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' STABLE STRICT;

CREATE OR REPLACE FUNCTION XML_PIID(VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' STABLE STRICT;

CREATE OR REPLACE FUNCTION Drop_Document(VARCHAR) RETURNS BOOL AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;
 
CREATE OR REPLACE FUNCTION Get_TagID(VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' IMMUTABLE STRICT;

CREATE OR REPLACE FUNCTION Get_AttID(VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' IMMUTABLE STRICT;
 
CREATE OR REPLACE FUNCTION Get_NSID(VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' IMMUTABLE STRICT;

CREATE OR REPLACE FUNCTION Get_PIID(VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' IMMUTABLE STRICT;

CREATE OR REPLACE FUNCTION CreateElement(INTEGER,VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;

CREATE OR REPLACE FUNCTION CreateProcessingInstruction(INTEGER,VARCHAR,VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;
 
CREATE OR REPLACE FUNCTION CreateTextNode(INTEGER,VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;

CREATE OR REPLACE FUNCTION CreateComment(INTEGER,VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;

CREATE OR REPLACE FUNCTION addChildElement(INTEGER,VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;

CREATE OR REPLACE FUNCTION addChildPI(INTEGER,VARCHAR,VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;

CREATE OR REPLACE FUNCTION addChildText(INTEGER,VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;

CREATE OR REPLACE FUNCTION addChildComment(INTEGER,VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;

-- CREATE OR REPLACE FUNCTION New_ChildElement(INTEGER,VARCHAR) RETURNS INTEGER AS
-- '/usr/local/lib/xpsql/libxpsql.so', 'addchildelement'
--  language 'C' STRICT;
-- 
-- CREATE OR REPLACE FUNCTION New_ChildPI(INTEGER,VARCHAR,VARCHAR) RETURNS INTEGER AS
-- '/usr/local/lib/xpsql/libxpsql.so', 'addchildpi'
--  language 'C' STRICT;
-- 
-- CREATE OR REPLACE FUNCTION New_ChildText(INTEGER,VARCHAR) RETURNS INTEGER AS
-- '/usr/local/lib/xpsql/libxpsql.so', 'addchildtext'
--  language 'C' STRICT;
-- 
-- CREATE OR REPLACE FUNCTION New_ChildComment(INTEGER,VARCHAR) RETURNS INTEGER AS
-- '/usr/local/lib/xpsql/libxpsql.so', 'addchildcomment'
--  language 'C' STRICT;

CREATE OR REPLACE FUNCTION SetAttribute(INTEGER,VARCHAR,VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;

CREATE OR REPLACE FUNCTION SetNamespace(INTEGER,VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;

CREATE OR REPLACE FUNCTION SetNamespace(INTEGER,VARCHAR,VARCHAR) RETURNS INTEGER AS
'/usr/local/lib/xpsql/libxpsql.so'
 language 'C' STRICT;

CREATE OR REPLACE FUNCTION appendChild(INTEGER,INTEGER) RETURNS BOOL AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' STRICT;

CREATE OR REPLACE FUNCTION insertBefore(INTEGER,INTEGER) RETURNS BOOL AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' STRICT;

CREATE OR REPLACE FUNCTION StringValue(INTEGER) RETURNS TEXT AS
'/usr/local/lib/xpsql/libxpsql.so'
 LANGUAGE 'C' STABLE STRICT;
 
CREATE or REPLACE FUNCTION toxml(INTEGER) RETURNS VARCHAR
  AS '/usr/local/lib/xpsql/libxpsql.so'
  LANGUAGE 'C' IMMUTABLE STRICT;

CREATE OR REPLACE FUNCTION cat_list(VARCHAR, VARCHAR) RETURNS VARCHAR AS
'
SELECT CASE
	WHEN $2 IS NULL OR $2 = '''' THEN $1
	WHEN $1 IS NULL OR $1 = '''' THEN $2
	ELSE $1 || $2
END
'LANGUAGE 'SQL';

--CREATE OR REPLACE FUNCTION IsUnited(INTEGER) RETURNS BOOLEAN AS
--'
--SELECT united FROM xml_path WHERE pathid = $1
--'LANGUAGE 'SQL';

CREATE AGGREGATE list(
	sfunc1=cat_list,
	basetype=VARCHAR,
	stype1=VARCHAR,
	initcond1=''
);

END;
